#
# spec file for package NetworkManager-libreswan
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           NetworkManager-libreswan
Version:        1.2.14
Release:        bp154.1.68
Summary:        Libreswan VPN client plugin for NetworkManager
License:        GPL-2.0-or-later
Group:          Productivity/Networking/System
URL:            https://gitlab.gnome.org/GNOME/NetworkManager-libreswan
Source0:        https://download.gnome.org/sources/NetworkManager-libreswan/1.2/%{name}-%{version}.tar.xz

BuildRequires:  intltool >= 0.35
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.32
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.4
BuildRequires:  pkgconfig(libnl-3.0) >= 3.2.8
BuildRequires:  pkgconfig(libnm)
BuildRequires:  pkgconfig(libnma) >= 1.2.0
BuildRequires:  pkgconfig(libsecret-1) >= 0.18

Requires:       /usr/sbin/ipsec
Provides:       NetworkManager-openswan = %{version}
Obsoletes:      NetworkManager-openswan < %{version}

%description
This package contains software for integrating the libreswan VPN
software with NetworkManager and the GNOME desktop.

%package -n NetworkManager-libreswan-gnome
Summary:        NetworkManager VPN plugin for libreswan - GNOME files
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}
Provides:       NetworkManager-openswan-gnome = %{version}
Obsoletes:      NetworkManager-openswan-gnome < %{version}

%description -n NetworkManager-libreswan-gnome
This package contains software for integrating VPN capabilities
with the libreswan server with NetworkManager (GNOME files).

%lang_package

%prep
%autosetup -p1

%build
%configure \
	--disable-static \
	%{nil}
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS
%config %{_sysconfdir}/dbus-1/system.d/nm-libreswan-service.conf
%{_libdir}/NetworkManager/libnm-vpn-plugin-libreswan.so
%{_vpnservicedir}/nm-libreswan-service.name
%{_libexecdir}/nm-libreswan-service
%{_libexecdir}/nm-libreswan-service-helper
%{_mandir}/man5/nm-settings-libreswan.5%{ext_man}

%files -n NetworkManager-libreswan-gnome
%{_libexecdir}/nm-libreswan-auth-dialog
%{_libdir}/NetworkManager/libnm-vpn-plugin-libreswan-editor.so
%dir %{_datadir}/appdata
%{_datadir}/appdata/network-manager-libreswan.metainfo.xml
%dir %{_datadir}/gnome-vpn-properties
%dir %{_datadir}/gnome-vpn-properties/libreswan
%{_datadir}/gnome-vpn-properties/libreswan/nm-libreswan-dialog.ui

%files lang -f %{name}.lang

%changelog
* Tue Jan 12 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.2.14:
  + Support Libreswan 4, which changed the name of some
    configuration parameters. Now the plugin can detect the
    Libreswan version and use the appropriate parameter names.
  + The auth helper in external UI mode can now be run without a
    display server. Future nmcli version will utilize this for
    handling the secrets without a graphical desktop.
  + Update strings for new dialog design in gnome-shell.
  + Updated translations.
* Fri May  1 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Set the path for the VPN service name file correctly to
  %%_vpnservicedir (provided by macros.NetworkManager).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Jul 31 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.2.12:
  + libnm-glib compatibility (NetworkManager < 1.0) is disabled by
    default. It can be enabled by passing --with-libnm-glib to
    configure script. Nobody should need it by now. Users that
    still use this are encourage to let us know before the
    libnm-glib support is removed for good.
  + Fixed the advanced dialog not working in Gnome.
  + Updated translations.
- Stop passing --without-libnm-glib to configure, no longer needed.
* Mon Oct 15 2018 bjorn.lie@gmail.com
- Update to version 1.2.10:
  + Fixed import/export feature.
  + Added support to the 'pfs' Libreswan option.
  + Updated translations.
* Tue Sep 25 2018 bjorn.lie@gmail.com
- Update to version 1.2.8:
  + GUI allows to set the remote id also for IKEv1 connections.
  + GUI "advanced" section as been moved to a separate dialog.
  + GUI allows to select IKEv2 certificate-based config.
  + Added support to many new Libreswan options: "'rightid',
    'narrowing', 'rekey', 'fragmentation', mobike' ... see man page
    for full list.
  + Added support for IKEv2.
  + Added nm-settings-libreswan man page to document supported
    options.
  + Added 'ikelifetime', 'salifetime' and 'rightsubnet' settings.
  + Updated translations.
* Tue Apr 10 2018 bjorn.lie@gmail.com
- Initial packaging of NetworkManager-libreswan, version 1.2.6.
